#include "project.h"
#include "stdio.h"

#define LM75B_I2C_SLAVE_ADDR (0x48)

char str[128] ; /* print buffer */
void print(char *str)
{
    UART_PutString(str) ;
}

void init_hardware(void)
{
    UART_Start() ;    
    I2C_Start() ;  
    CyGlobalIntEnable; /* Enable global interrupts. */    
}

void splash(void)
{
    sprintf(str, "I2C Reset Test (%s %s)\n", __DATE__, __TIME__) ;
    print(str) ;
}

uint8_t myI2C_ReadByte(uint8_t reg_addr)
{
    uint8_t status ;
    uint8_t value = 0 ;
    
    I2C_MasterClearStatus();

    status = I2C_MasterSendStart(LM75B_I2C_SLAVE_ADDR, I2C_WRITE_XFER_MODE) ;
    
    if (I2C_MSTR_NO_ERROR == status) {
        I2C_MasterWriteByte(reg_addr); 
        status = I2C_MasterSendRestart(LM75B_I2C_SLAVE_ADDR, I2C_READ_XFER_MODE);  
    }
    
    if (I2C_MSTR_NO_ERROR == status) {   
        value = I2C_MasterReadByte(I2C_ACK_DATA); // read manufacturers ID from device
    }
    I2C_MasterSendStop();  
    
    return(value) ;
}

/**
 * From 10.1.1 General Call Address The I2C-BUS SPECIFICTIAON Version 2.1
 * General call address 0x00 and comand 0x06
 * is supposed to reset devices on the bus
 * if they are capable of responding to this command.
 */
uint8_t i2c_software_reset(void)
{
    uint8_t status ;
    uint8_t global_address = 0x00 ;
    uint8_t sw_reset = 0x06 ;
    
    I2C_MasterClearStatus();

    status = I2C_MasterSendStart(global_address, I2C_WRITE_XFER_MODE) ;
    
    if (I2C_MSTR_NO_ERROR == status) {
        status = I2C_MasterWriteByte(sw_reset); 
    }
    
    I2C_MasterSendStop();  
    
    return(status) ;
}

#define I2C_CLK_DELAY     5 /* 10us for 100KHz */
void toggle_scl(int num)
{
    int i ;
    for (i = 0 ; i < num ; i++ ) {
        SCL_Write(1) ;
        CyDelayUs(I2C_CLK_DELAY) ;
        SCL_Write(0) ;
        CyDelayUs(I2C_CLK_DELAY) ;
    }
    SCL_Write(1) ;    
}

int i2c_bus_reset(void)
{
    int result = 0 ;
    int sda_bypass, scl_bypass ;
    int try_count = 10 ;
        
    scl_bypass = SCL_BYP ;             /* save scl bypass value */
    sda_bypass = SDA_BYP ;             /* save sda bypass value */
    
    SCL_SetDriveMode(PIN_DM_STRONG) ;  /* Strong CMOS Output */
    SCL_BYP = 0 ;                      /* disconnect SCL pin from I2C and enable DR */  
    SDA_SetDriveMode(PIN_DM_DIG_HIZ) ; /* Digital HiZ input */
    SDA_BYP = 0 ;                      /* disconnect SDA pin from I2C */
    
    do {
        toggle_scl(16) ;

        result = SDA_Read() && SCL_Read() ;
        try_count-- ;
        if (try_count <= 0) {
            break ;
        }
    } while(result == 0) ;
        
    SCL_SetDriveMode(PIN_DM_OD_LO) ; /* Open drain - drive low */
    SCL_BYP = scl_bypass ;           /* reconnect SCL to I2C   */
    SDA_SetDriveMode(PIN_DM_OD_LO) ; /* Open drain - drive low */
    SDA_BYP = sda_bypass ;           /* reconnect SDA to I2C   */
    
//  i2c_software_reset() ; /* may not be necessary */
        
    return(result) ;
}


int main(void)
{
    uint8_t data ;
    uint8_t addr = 0 ;
    int i ;
    
    init_hardware() ;

    splash() ;
     
    for(;;)
    {       
        for (i = 0 ; i < 5 ; i++ ) {
            data = myI2C_ReadByte(addr) ;        
            sprintf(str, "%d\n", data) ;
            print(str) ;
            CyDelay(1000) ;
        }
        
        print("Resetting I2C Bus ... ") ;
        if (i2c_bus_reset()) {
            print("OK!\n") ;
        } else {
            print("Failed!\n") ;
        }
        CyDelay(1000) ;
    }
}

/* [] END OF FILE */
